#
# spec file for package python-DataProperty
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-DataProperty
Version:        1.0.1
Release:        1.7
Summary:        Python library for extract property from data
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/thombashi/DataProperty
Source:         https://files.pythonhosted.org/packages/source/D/DataProperty/DataProperty-%{version}.tar.gz
BuildRequires:  %{python_module setuptools >= 38.3.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-mbstrdecoder >= 1.0.0
Requires:       python-typepy >= 1.1.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module mbstrdecoder >= 1.0.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= 2.8.0}
BuildRequires:  %{python_module pytz >= 2018.9}
BuildRequires:  %{python_module tcolorpy}
BuildRequires:  %{python_module typepy >= 1.1.0}
# /SECTION
%python_subpackages

%description
Python library for extract property from data.

%prep
%setup -q -n DataProperty-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Required by termcolor to have colors in the tests
export FORCE_COLOR=1
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/dataproperty*
%{python_sitelib}/DataProperty*

%changelog
* Thu Jul 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.1:
  * Fix `ColumnDataProperty.merge` method
  * Add `DataPropertyMatrix` to the package root
  * Improve type annotations
  * Drop support for Python 3.6
  * Modify to use `pypa/build` for package build
  * Update `[build-system]`
  * Add `zip_safe=False`
  * Add `__all__` to `__init__.py`
  * Improve type annotations
  * Remove a deprecated function: `set_log_level`
  * Remove `is_multibyte_str` function
* Thu May 18 2023 Dirk Müller <dmueller@suse.com>
- update to 0.55.1
  * Python 3.11 support
  * Switches to tcolorpy
* Thu Jan 26 2023 Daniel Garcia <daniel.garcia@suse.com>
- Fix tests forcing terminal colors before running tests
* Tue Aug  2 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to v0.55.0:
  * Add default_format_flags property
  * Fix PyPy version specification
  * Update key of steps
  * Use extras in tox.ini instead of self-referencing the package in deps
  * Replace to use MAKE
  * Remove basepython from testenvs
  * Fix concurrency.group of a job
  * Add tool.black.target-version to pyproject.toml
- Changes from v0.54.2
  * Remove pytype
  * Fix DataProperty.get_padding_len method return improper len when the inputs
    are dict
  * Fix preprocess failed when the inputs are dict
- Changes from v0.54.1
  * Fix normalization order of type hints
- Changes from v0.54.0
  * Improve normalize_type_hint
  * Add setup-ci target to Makefile
  * Add strategy.matrix.exclude to a workflow
- Changes from v0.53.0
  * Modify type annotation of column_type_hints property
  * Modify to accept type hints as strings
  * Add normalize_type_hint function
  * Add dequote to parameter to Preprocessor class
  * Add max_precision property to DataPropertyExtractor class
  * Add jupyter extra to black
  * Bump Python 3.10 RC version
- Changes from v0.52.0
  * Add support for max_precision
- Changes from v0.51.0
  * Modify to use Python 3.6 syntax
  * Add support for Python 3.10
  * Drop support for Python 3.5
  * Improve calculation of ascii char width of the body
  * Add max_decimal_places argument to get_number_of_digit function
  * Improve precision for real number values
  * Add support for string with thousand separators as integer
* Mon May  3 2021 Martin Hauke <mardnh@gmx.de>
- Update to 0.50.1
  * Change max_workers initial value to one to avoid problems
    caused by multiprocess.
  * Modify type annotations.
* Wed Jul  8 2020 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 0.49.1
  - no upstream changelog
* Mon May  4 2020 Johannes Grassler <johannes.grassler@suse.com>
- Update to version 0.48.2
  * Update testenv:build.commands
  * Make max_workers to 1 when executed from pytest
* Fri Apr 17 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 0.48.1
  * Drop Python 2 support
  * Add metaclass to AbstractContainer class
  * Improve dictionary type detection (=bump dependencies)
  * Small fixes
* Wed Mar 25 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 0.46.4
  * minor fixes
* Sun Feb 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.46.3:
  * no upstream changelog
* Sat Feb  8 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.45.0
- Specfile cleanup
- Run testsuite
* Fri May 10 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.43.0
